aboutsummaryrefslogtreecommitdiffstats
path: root/src/queue/Playlist.hxx
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/queue/Playlist.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/queue/Playlist.hxx b/src/queue/Playlist.hxx
index 75e861a82..581d2a73b 100644
--- a/src/queue/Playlist.hxx
+++ b/src/queue/Playlist.hxx
@@ -228,11 +228,11 @@ public:
unsigned song_id, uint8_t priority);
/**
* Sets the start_ms and end_ms attributes on the song
* with the specified id.
*/
bool SetSongIdRange(PlayerControl &pc, unsigned id,
- unsigned start_ms, unsigned end_ms,
+ SongTime start, SongTime end,
Error &error);
bool AddSongIdTag(unsigned id, TagType tag_type, const char *value,
@@ -228,11 +228,11 @@ public:
unsigned song_id, uint8_t priority);
/**
- * Sets the start_ms and end_ms attributes on the song
+ * Sets the start_time and end_time attributes on the song
* with the specified id.
*/